# Landmark Detection

Neurobooth library for landmark detection of face features, face mesh, pose, etc. 

Installable with `pip install neurobooth`

If you have docker and docker-compose installed, you can run the following to set up a jupyter environment:

```
docker-compose build
docker-compose up
```